@@ -19,9 +19,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 // for all others, include the necessary headers
 #ifndef WX_PRECOMP
@@ -198,13 +195,25 @@ class MyDateDialog : public wxDialog
 public:
     MyDateDialog(wxWindow *parent, const wxDateTime& dt, int dtpStyle);
 
-    wxDateTime GetDate() const { return m_datePicker->GetValue(); }
+    wxDateTime GetDate() const
+    {
+#if wxUSE_DATEPICKCTRL_GENERIC
+        if ( m_datePickerGeneric )
+            return m_datePickerGeneric->GetValue();
+#endif // wxUSE_DATEPICKCTRL_GENERIC
+
+        return m_datePicker->GetValue();
+    }
 
 private:
     void OnDateChange(wxDateEvent& event);
 
 
-    wxDatePickerCtrlBase *m_datePicker;
+    wxDatePickerCtrl *m_datePicker;
+#if wxUSE_DATEPICKCTRL_GENERIC
+    wxDatePickerCtrlGeneric *m_datePickerGeneric;
+#endif // wxUSE_DATEPICKCTRL_GENERIC
+
     wxStaticText *m_dateText;
 
 
@@ -221,12 +230,24 @@ class MyTimeDialog : public wxDialog
 public:
     MyTimeDialog(wxWindow* parent);
 
-    wxDateTime GetTime() const { return m_timePicker->GetValue(); }
+    wxDateTime GetTime() const
+    {
+#if wxUSE_TIMEPICKCTRL_GENERIC
+        if ( m_timePickerGeneric )
+            return m_timePickerGeneric->GetValue();
+#endif // wxUSE_TIMEPICKCTRL_GENERIC
+
+        return m_timePicker->GetValue();
+    }
 
 private:
     void OnTimeChange(wxDateEvent& event);
 
-    wxTimePickerCtrlBase* m_timePicker;
+    wxTimePickerCtrl* m_timePicker;
+#if wxUSE_TIMEPICKCTRL_GENERIC
+    wxTimePickerCtrlGeneric* m_timePickerGeneric;
+#endif // wxUSE_TIMEPICKCTRL_GENERIC
+
     wxStaticText* m_timeText;
 
     wxDECLARE_EVENT_TABLE();
@@ -932,20 +953,36 @@ wxEND_EVENT_TABLE()
 MyDateDialog::MyDateDialog(wxWindow *parent, const wxDateTime& dt, int dtpStyle)
         : wxDialog(parent, wxID_ANY, wxString("Calendar: Choose a date"))
 {
+    wxWindow* datePickerWindow = NULL;
+
 #if wxUSE_DATEPICKCTRL_GENERIC
+    m_datePickerGeneric = NULL;
+    m_datePicker = NULL;
+
     wxFrame *frame = (wxFrame *)wxGetTopLevelParent(parent);
     if ( frame && frame->GetMenuBar()->IsChecked(Calendar_DatePicker_Generic) )
-        m_datePicker = new wxDatePickerCtrlGeneric(this, wxID_ANY, dt,
-                                                   wxDefaultPosition,
-                                                   wxDefaultSize,
-                                                   dtpStyle);
+    {
+        m_datePickerGeneric = new wxDatePickerCtrlGeneric(this, wxID_ANY, dt,
+                                                          wxDefaultPosition,
+                                                          wxDefaultSize,
+                                                          dtpStyle);
+        m_datePickerGeneric->SetRange(wxDateTime(1, wxDateTime::Jan, 1900),
+                                      wxDefaultDateTime);
+
+        datePickerWindow = m_datePickerGeneric;
+    }
     else
 #endif // wxUSE_DATEPICKCTRL_GENERIC
-    m_datePicker = new wxDatePickerCtrl(this, wxID_ANY, dt,
-                                        wxDefaultPosition, wxDefaultSize,
-                                        dtpStyle);
-    m_datePicker->SetRange(wxDateTime(1, wxDateTime::Jan, 1900),
-                            wxDefaultDateTime);
+    {
+        m_datePicker = new wxDatePickerCtrl(this, wxID_ANY, dt,
+                                            wxDefaultPosition, wxDefaultSize,
+                                            dtpStyle);
+        m_datePicker->SetRange(wxDateTime(1, wxDateTime::Jan, 1900),
+                               wxDefaultDateTime);
+
+        datePickerWindow = m_datePicker;
+    }
+
     m_dateText = new wxStaticText(this, wxID_ANY,
                                   dt.IsValid() ? dt.FormatISODate()
                                                : wxString());
@@ -953,7 +990,7 @@ MyDateDialog::MyDateDialog(wxWindow *parent, const wxDateTime& dt, int dtpStyle)
     const wxSizerFlags flags = wxSizerFlags().Centre().Border();
     wxFlexGridSizer* const sizerMain = new wxFlexGridSizer(2);
     sizerMain->Add(new wxStaticText(this, wxID_ANY, "Enter &date:"), flags);
-    sizerMain->Add(m_datePicker, flags);
+    sizerMain->Add(datePickerWindow, flags);
 
     sizerMain->Add(new wxStaticText(this, wxID_ANY, "Date in ISO format:"),
                    flags);
@@ -990,20 +1027,31 @@ wxEND_EVENT_TABLE()
 MyTimeDialog::MyTimeDialog(wxWindow *parent)
         : wxDialog(parent, wxID_ANY, wxString("Calendar: Choose time"))
 {
+    wxWindow* timePickerWindow = NULL;
+
 #if wxUSE_TIMEPICKCTRL_GENERIC
+    m_timePickerGeneric = NULL;
+    m_timePicker = NULL;
+
     wxFrame *frame = (wxFrame *)wxGetTopLevelParent(parent);
     if ( frame && frame->GetMenuBar()->IsChecked(Calendar_TimePicker_Generic) )
-        m_timePicker = new wxTimePickerCtrlGeneric(this, wxID_ANY);
+    {
+        m_timePickerGeneric = new wxTimePickerCtrlGeneric(this, wxID_ANY);
+        timePickerWindow = m_timePickerGeneric;
+    }
     else
 #endif // wxUSE_TIMEPICKCTRL_GENERIC
     m_timePicker = new wxTimePickerCtrl(this, wxID_ANY);
-    m_timeText = new wxStaticText(this, wxID_ANY,
-                                  m_timePicker->GetValue().FormatISOTime());
+
+    if ( !timePickerWindow )
+        timePickerWindow = m_timePicker;
+
+    m_timeText = new wxStaticText(this, wxID_ANY, GetTime().FormatISOTime());
 
     const wxSizerFlags flags = wxSizerFlags().Centre().Border();
     wxFlexGridSizer* const sizerMain = new wxFlexGridSizer(2);
     sizerMain->Add(new wxStaticText(this, wxID_ANY, "Enter &time:"), flags);
-    sizerMain->Add(m_timePicker, flags);
+    sizerMain->Add(timePickerWindow, flags);
 
     sizerMain->Add(new wxStaticText(this, wxID_ANY, "Time in ISO format:"),
                    flags);
