@@ -25,6 +25,7 @@
 
 #ifndef WX_PRECOMP
     #include "wx/frame.h"
+    #include "wx/app.h"     // GetAppDisplayName()
     #include "wx/icon.h"
     #include "wx/log.h"
 #endif
@@ -34,6 +35,7 @@
 
 #include "wx/gtk/private.h"
 #include "wx/gtk/private/gtk3-compat.h"
+#include "wx/gtk/private/stylecontext.h"
 #include "wx/gtk/private/win_gtk.h"
 
 #ifdef GDK_WINDOWING_X11
@@ -55,6 +57,7 @@ static wxTopLevelWindowGTK *g_activeFrame = NULL;
 
 extern wxCursor g_globalCursor;
 extern wxCursor g_busyCursor;
+extern bool g_inSizeAllocate;
 
 #ifdef GDK_WINDOWING_X11
 // Whether _NET_REQUEST_FRAME_EXTENTS support is working
@@ -238,6 +241,9 @@ size_allocate(GtkWidget*, GtkAllocation* alloc, wxTopLevelWindowGTK* win)
     if (win->m_clientWidth  != alloc->width ||
         win->m_clientHeight != alloc->height)
     {
+        const bool save_inSizeAllocate = g_inSizeAllocate;
+        g_inSizeAllocate = true;
+
         win->m_clientWidth  = alloc->width;
         win->m_clientHeight = alloc->height;
 
@@ -270,6 +276,8 @@ size_allocate(GtkWidget*, GtkAllocation* alloc, wxTopLevelWindowGTK* win)
             win->HandleWindowEvent(event);
         }
         // else the window is currently unmapped, don't generate size events
+
+        g_inSizeAllocate = save_inSizeAllocate;
     }
 }
 }
@@ -340,6 +348,16 @@ void wxTopLevelWindowGTK::GTKConfigureEvent(int x, int y)
 // "realize" from m_widget
 //-----------------------------------------------------------------------------
 
+#if GTK_CHECK_VERSION(3,10,0)
+extern "C" {
+static void findTitlebar(GtkWidget* widget, void* data)
+{
+    if (GTK_IS_HEADER_BAR(widget))
+        *static_cast<GtkWidget**>(data) = widget;
+}
+}
+#endif
+
 // we cannot the WM hints and icons before the widget has been realized,
 // so we do this directly after realization
 
@@ -349,11 +367,31 @@ void wxTopLevelWindowGTK::GTKHandleRealized()
 
     GdkWindow* window = gtk_widget_get_window(m_widget);
 
-#ifdef __WXGTK3__
-    // Don't set WM decorations if GTK is using Client Side Decorations
-    if (gtk_style_context_has_class(gtk_widget_get_style_context(m_widget), "csd"))
-        m_gdkDecor = 0;
-#endif
+#if GTK_CHECK_VERSION(3,10,0)
+    if (wx_is_at_least_gtk3(10))
+    {
+        GtkWidget* titlebar = NULL;
+        gtk_container_forall(GTK_CONTAINER(m_widget), findTitlebar, &titlebar);
+        if (titlebar)
+        {
+#if GTK_CHECK_VERSION(3,12,0)
+            if (m_gdkDecor && wx_is_at_least_gtk3(12))
+            {
+                char layout[sizeof("icon,menu:minimize,maximize,close")];
+                snprintf(layout, sizeof(layout), "icon%s:%s%s%s",
+                     m_gdkDecor & GDK_DECOR_MENU ? ",menu" : "",
+                     m_gdkDecor & GDK_DECOR_MINIMIZE ? "minimize," : "",
+                     m_gdkDecor & GDK_DECOR_MAXIMIZE ? "maximize," : "",
+                     m_gdkFunc & GDK_FUNC_CLOSE ? "close" : "");
+                gtk_header_bar_set_decoration_layout(GTK_HEADER_BAR(titlebar), layout);
+            }
+#endif // 3.12
+            // Don't set WM decorations when GTK is using Client Side Decorations
+            m_gdkDecor = 0;
+        }
+    }
+#endif // 3.10
+
     gdk_window_set_decorations(window, (GdkWMDecoration)m_gdkDecor);
     gdk_window_set_functions(window, (GdkWMFunction)m_gdkFunc);
 
@@ -599,6 +637,11 @@ bool wxTopLevelWindowGTK::Create( wxWindow *parent,
 
     m_title = title;
 
+#ifndef __WXGTK4__
+    // Gnome uses class as display name
+    gdk_set_program_class(wxTheApp->GetAppDisplayName().utf8_str());
+#endif
+
     // NB: m_widget may be !=NULL if it was created by derived class' Create,
     //     e.g. in wxTaskBarIconAreaGTK
     if (m_widget == NULL)
@@ -806,7 +849,13 @@ bool wxTopLevelWindowGTK::Create( wxWindow *parent,
         gtk_widget_set_size_request(m_widget, w, h);
     }
 
-    g_signal_connect(gtk_settings_get_default(), "notify::gtk-theme-name",
+    // Note that we need to connect after this signal in order to let the
+    // normal g_signal_connect() in wxSystemSettings code to run before our
+    // handler: this ensures that system settings cache is cleared before the
+    // user-defined wxSysColourChangedEvent handlers using wxSystemSettings
+    // methods are executed, which is important as otherwise they would use the
+    // old colours etc.
+    g_signal_connect_after(gtk_settings_get_default(), "notify::gtk-theme-name",
         G_CALLBACK(notify_gtk_theme_name), this);
 
     return true;
@@ -861,6 +910,11 @@ bool wxTopLevelWindowGTK::ShowFullScreen(bool show, long)
     if (show == m_fsIsShowing)
         return false; // return what?
 
+    // documented behaviour is to show the window if it's still hidden when
+    // showing it full screen
+    if (show)
+        Show();
+
     m_fsIsShowing = show;
 
 #if defined(GDK_WINDOWING_X11) && !defined(__WXGTK4__)
@@ -943,11 +997,6 @@ bool wxTopLevelWindowGTK::ShowFullScreen(bool show, long)
     }
 #endif // GDK_WINDOWING_X11
 
-    // documented behaviour is to show the window if it's still hidden when
-    // showing it full screen
-    if (show)
-        Show();
-
     return true;
 }
 
@@ -1779,3 +1828,12 @@ bool wxTopLevelWindowGTK::CanSetTransparent()
                            "Composite", &opcode, &event, &error);
 #endif
 }
+
+wxVisualAttributes wxTopLevelWindowGTK::GetDefaultAttributes() const
+{
+    wxVisualAttributes attrs(GetClassDefaultAttributes());
+#ifdef __WXGTK3__
+    wxGtkStyleContext().AddWindow().Bg(attrs.colBg);
+#endif
+    return attrs;
+}
