@@ -45,6 +45,7 @@
 
 // mac
 #include "wx/osx/private.h"
+#include "wx/display.h"
 
 #if defined(WXMAKINGDLL_CORE)
 #   include <mach-o/dyld.h>
@@ -157,50 +158,39 @@ void wxApp::MacReopenApp()
     // if there is no open window -> create a new one
     // if all windows are hidden -> show the first
     // if some windows are not hidden -> do nothing
+    //
+    // Showing hidden windows is not really always a good solution, also non-modal dialogs when closed end up
+    // as hidden TLWs, so do preferences and some classes like wxTaskBarIconWindow use placeholder TLWs.
+    // We don't want to reshow those, so let's just reopen the minimized a.k.a. iconized TLWs.
 
+    wxTopLevelWindow* firstIconized = NULL;
     wxWindowList::compatibility_iterator node = wxTopLevelWindows.GetFirst();
-    if ( !node )
-    {
-        MacNewFile() ;
-    }
-    else
-    {
-        wxTopLevelWindow* firstIconized = NULL ;
-        wxTopLevelWindow* firstHidden = NULL ;
-        while (node)
-        {
-            wxTopLevelWindow* win = (wxTopLevelWindow*) node->GetData();
-            if ( !win->IsShown() )
-            {
-                // make sure we don't show 'virtual toplevel windows' like wxTaskBarIconWindow
-                if ( firstHidden == NULL && ( wxDynamicCast( win, wxFrame ) || wxDynamicCast( win, wxDialog ) ) )
-                   firstHidden = win ;
-            }
-            else if ( win->IsIconized() )
-            {
-                if ( firstIconized == NULL )
-                    firstIconized = win ;
-            }
-            else
-            {
-                // we do have a visible, non-iconized toplevelwindow -> do nothing
-                return;
-            }
 
-            node = node->GetNext();
+    while (node)
+    {
+        wxTopLevelWindow* win = (wxTopLevelWindow*) node->GetData();
+        if ( win->IsShown() )
+        {
+            // we do have a visible, non-iconized toplevelwindow -> do nothing
+            return;
+        }
+        else if ( win->IsIconized() )
+        {
+            if ( firstIconized == NULL )
+                firstIconized = win;
         }
 
-        if ( firstIconized )
-            firstIconized->Iconize( false ) ;
-        
-        // showing hidden windows is not really always a good solution, also non-modal dialogs when closed end up
-        // as hidden tlws, we don't want to reshow those, so let's just reopen the minimized a.k.a. iconized tlws
-        // unless we find a regression ...
-#if 0
-        else if ( firstHidden )
-            firstHidden->Show( true );
-#endif
+        node = node->GetNext();
     }
+
+    if ( firstIconized )
+    {
+        firstIconized->Iconize(false);
+        return;
+    }
+
+    // no window was shown, we need to create a new one
+    MacNewFile();
 }
 
 #if wxOSX_USE_COCOA_OR_IPHONE
@@ -236,16 +226,14 @@ bool wxApp::OSXOnShouldTerminate()
 
 #if wxDEBUG_LEVEL && wxOSX_USE_COCOA_OR_CARBON
 
-pascal static void
-wxMacAssertOutputHandler(OSType WXUNUSED(componentSignature),
-                         UInt32 WXUNUSED(options),
+extern "C" void
+wxMacAssertOutputHandler(const char *WXUNUSED(componentName),
                          const char *assertionString,
                          const char *exceptionLabelString,
                          const char *errorString,
                          const char *fileName,
                          long lineNumber,
-                         void *value,
-                         ConstStr255Param WXUNUSED(outputMsg))
+                         int errorCode)
 {
     // flow into assert handling
     wxString fileNameStr ;
@@ -265,18 +253,18 @@ wxMacAssertOutputHandler(OSType WXUNUSED(componentSignature),
     errorStr = (errorString!=0) ? errorString : "" ;
 #endif
 
-#if 1
-    // flow into log
-    wxLogDebug( wxT("AssertMacros: %s %s %s file: %s, line: %ld (value %p)\n"),
+    // turn this on, if you want the macOS asserts to flow into log, otherwise they are handled via wxOnAssert
+#if 0
+    wxLogDebug( wxT("AssertMacros: %s %s %s file: %s, line: %ld (error code %d)\n"),
         assertionStr.c_str() ,
         exceptionStr.c_str() ,
         errorStr.c_str(),
         fileNameStr.c_str(), lineNumber ,
-        value ) ;
+               errorCode ) ;
 #else
 
     wxOnAssert(fileNameStr, lineNumber , assertionStr ,
-        wxString::Format( wxT("%s %s value (%p)") , exceptionStr, errorStr , value ) ) ;
+        wxString::Format( wxT("%s %s value (%d)") , exceptionStr, errorStr , errorCode ) ) ;
 #endif
 }
 
@@ -284,12 +272,6 @@ wxMacAssertOutputHandler(OSType WXUNUSED(componentSignature),
 
 bool wxApp::Initialize(int& argc, wxChar **argv)
 {
-    // Mac-specific
-
-#if wxDEBUG_LEVEL && wxOSX_USE_COCOA_OR_CARBON
-    InstallDebugAssertOutputHandler( NewDebugAssertOutputHandlerUPP( wxMacAssertOutputHandler ) );
-#endif
-
     /*
      Cocoa supports -Key value options which set the user defaults key "Key"
      to the value "value"  Some of them are very handy for debugging like
@@ -343,6 +325,18 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
     return true;
 }
 
+#ifdef __WXOSX_COCOA__
+void wxCGDisplayReconfigurationCallBack(CGDirectDisplayID WXUNUSED(display),
+                                        CGDisplayChangeSummaryFlags WXUNUSED(flags),
+                                        void* WXUNUSED(userInfo))
+{
+    // flags could be tested to know about removal, addition etc. right now
+    // this is called multiple times for a change but for invalidating the
+    // cache these things don't matter yet
+    wxDisplay::InvalidateCache();
+}
+#endif
+
 bool wxApp::OnInitGui()
 {
     if ( !wxAppBase::OnInitGui() )
@@ -351,6 +345,10 @@ bool wxApp::OnInitGui()
     if ( !DoInitGui() )
         return false;
 
+#ifdef __WXOSX_COCOA__
+    CGDisplayRegisterReconfigurationCallback(wxCGDisplayReconfigurationCallBack, NULL);
+#endif
+
     return true ;
 }
 
@@ -423,7 +421,7 @@ void wxApp::OnIdle(wxIdleEvent& WXUNUSED(event))
     // either events to the threads other than main or events posted with
     // wxPostEvent() functions
 #ifndef __WXUNIVERSAL__
-#if wxUSE_MENUS
+#if wxUSE_MENUBAR
   if (!wxMenuBar::MacGetInstalledMenuBar() && wxMenuBar::MacGetCommonMenuBar())
     wxMenuBar::MacGetCommonMenuBar()->MacInstallMenuBar();
 #endif
